@@ -8,6 +8,8 @@
 ## 2024-09-03 call sim.onepopn from simulate.R if !usefxi
 ## 2024-09-09 various edits
 ## 2024-09-11 use mvtnorm instead of MASS
+## 2024-10-04 improved detectpar for unobserved AC in simfxiAC
+## 2024-10-04 added debugging points
 
 # Murray Efford and Yan Ru Choo
 ################################################################################
@@ -25,8 +27,10 @@ defaulttestfn <- function(realised, expected){
     sum((sqrt(realised) - sqrt(expected))^2)
 }
 
-simfxiAC <- function (object, bytrap) {
-
+simfxiAC <- function (object, bytrap, debug) {
+    
+    if (debug == 1) browser()
+    
     # -----------------------------------
     # sample one location of each _observed_ animal from its pdf
     fxiList <- fxi(object)
@@ -38,46 +42,54 @@ simfxiAC <- function (object, bytrap) {
     attr(obspop, 'boundingbox') <- attr(mask, 'boundingbox')
     rownames(obspop) <- names(fxiList)
     
-    # -----------------------------------
-    # sample unobserved AC from their pdf
-    
+    # --------------------------------------------
+    # sample _unobserved_ AC from their common pdf
+
     # density of unobserved AC
-    # this code is also in fxTotal
     Dstar <- predictDsurface(object)
     Dstar <- covariates(Dstar)$D.0
-    
+
     # make a null starting popn
     unobspop <- sim.popn(0, attr(obspop, 'boundingbox'), buffer = 0, covariates = NULL) 
     CH <- object$capthist
     n <- nrow(CH)
     
+    # number of unobserved AC
     Nstar <- sum(Dstar) * attr(mask, 'area')
-    if (object$details$distribution == 'poisson') {
-        Nstar <- rpois(1, Nstar)
-    }
-
+    
     if (Nstar < n) {
         warning("resampled N less than number observed; unobserved not simulated")
     }
     else if (Nstar > n) {
-        detpar <- detectpar(object, byclass = TRUE, bytrap = bytrap) 
-        ## if bytrap, detpar[[i]] is trap x parameter dataframe for class i
-        if (is.na(detpar[[1]]['pmix'])) detpar <- list(c(detpar, pmix = 1))
+        if (debug == 2) browser()
+        # detectpar0 is an internal function that gets naive detection parameters
+        # assume 1 session, no time variation
+        # returns dataframe
+        detpar <- detectpar0(object, bytrap = bytrap, byclass = TRUE) 
+        # split dataframe by latent class, dropping 'class' column etc.
+        pnames <- parnames(object$detectfn[1])
+        if ('pmix' %in% names(detpar)) pnames <- c(pnames, 'pmix')
+        detpar <- split(subset(detpar, select = pnames), detpar$class)
         for (i in 1:length(detpar)) {
+            ## if bytrap, dp is trap x parameter dataframe for class i
+            dp <- as.list(detpar[[i]])
+            pmix <- if (is.null(dp$pmix)) 1 else dp$pmix[1]
             pd <- pdot(X = mask, traps = traps(CH), detectfn = object$detectfn,
-                       detectpar = detpar[[i]], noccasions = ncol(CH))
+                       detectpar = dp, noccasions = ncol(CH))
             # sample locations of unobserved AC for i-th class
             pop <- sim.popn (
-                Nbuffer = (Nstar-n) * detpar[[i]]$pmix,  # number
-                D       = Dstar * (1 - pd),              # spatial distribution only
+                Nbuffer = (Nstar-n) * pmix,    # number
+                D       = Dstar * (1 - pd),    # spatial distribution only
                 core    = mask, 
                 model2D = 'IHP', 
-                Ndist   = 'fixed', 
+                Ndist   = if (object$details$distribution == 'poisson') 'poisson' else 'fixed', 
                 covariates = NULL
             )
             if (nrow(pop)>0) unobspop <- rbind(unobspop, pop)
         }
-        rownames(unobspop) <- paste0('N', 1:nrow(unobspop))
+        if (nrow(unobspop)>0) {
+            rownames(unobspop) <- paste0('N', 1:nrow(unobspop))
+        }
     }
 
     # -----------------------------------
@@ -101,21 +113,25 @@ simfxiAC <- function (object, bytrap) {
     popn
 }
 
-MCgof.secrlist <- function (object, nsim = 100, statfn = NULL, testfn = NULL,
-                        seed = NULL, ncores = 1, clustertype = c("PSOCK","FORK"), 
-                        usefxi = TRUE, useMVN = TRUE, Ndist = NULL, quiet = FALSE, ...)
-    
+MCgof.secrlist <- function (
+        object, nsim = 100, statfn = NULL, testfn = NULL,
+        seed = NULL, ncores = 1, clustertype = c("PSOCK","FORK"), 
+        usefxi = TRUE, useMVN = TRUE, Ndist = NULL, quiet = FALSE,
+        debug = FALSE, ...)
 {
     out <- lapply(object, MCgof, 
                   nsim = nsim, statfn = statfn, testfn = testfn,
                   seed = seed, ncores = ncores, clustertype = clustertype, 
-                  usefxi = usefxi, useMVN = useMVN, Ndist = NULL, quiet = quiet, ...)
+                  usefxi = usefxi, useMVN = useMVN, Ndist = Ndist, quiet = quiet,
+                  debug = debug, ...)
     names(out) <- names(object)
 }
 
-MCgof.secr <- function (object, nsim = 100, statfn = NULL, testfn = NULL,
-                   seed = NULL, ncores = 1, clustertype = c("PSOCK","FORK"), 
-                   usefxi = TRUE, useMVN = TRUE, Ndist = NULL, quiet = FALSE, ...)
+MCgof.secr <- function (
+        object, nsim = 100, statfn = NULL, testfn = NULL,
+        seed = NULL, ncores = 1, clustertype = c("PSOCK","FORK"), 
+        usefxi = TRUE, useMVN = TRUE, Ndist = NULL, quiet = FALSE, 
+        debug = FALSE, ...)
     
 {
     #---------------------------------------------------------------------------
@@ -138,10 +154,11 @@ MCgof.secr <- function (object, nsim = 100, statfn = NULL, testfn = NULL,
         # -----------------------------------------------
         # draw randomized AC
         if (usefxi) {
-            popn <- simfxiAC(object, bytrap)
+            popn <- simfxiAC(object, bytrap, debug)
         }
         else {
             Darray <- getDensityArray (predictDsurface(object))
+            # sim.onepopn() is in simulate.R
             popn <- sim.onepopn(object, Darray)[[1]]
         }
         
@@ -165,6 +182,8 @@ MCgof.secr <- function (object, nsim = 100, statfn = NULL, testfn = NULL,
         Tsim <- statfn(simCH)
         Texp <- statfn(expCH)
         
+        if (debug == 3) browser()
+        
         if (!quiet && ncores == 1) setTxtProgressBar(progressbar, i)
         list(Tsim = Tsim, Texp = Texp, par = object$fit$par, popn = popn)
         
@@ -179,8 +198,9 @@ MCgof.secr <- function (object, nsim = 100, statfn = NULL, testfn = NULL,
         # addzeroCH is internal secr function
         paddedCH <- addzeroCH(CH, N - n, prefix = 'N')
         Tobs <- statfn(paddedCH)
-        obs <- testfn(Tobs[[stat]],       capti$Texp[[stat]])
-        sim <- testfn(capti$Tsim[[stat]], capti$Texp[[stat]])
+        obs <- testfn(Tobs[[stat]],       capti$Texp[[stat]], ...)
+        sim <- testfn(capti$Tsim[[stat]], capti$Texp[[stat]], ...)
+        if (debug == 4) browser()
         c(Tobs = obs, Tsim = sim, p = sim>obs)  
     }   # end of ft
     #---------------------------------------------------------------------------
@@ -249,7 +269,6 @@ MCgof.secr <- function (object, nsim = 100, statfn = NULL, testfn = NULL,
     ## action starts here
     
     ptm  <- proc.time()
-    
     ## Does model have differences in detection parameters between traps?
     ## this is conditional to save time in pdot
     bytrap <- length(unique(apply(object$design0$PIA, 4, mean)))>1
@@ -262,6 +281,7 @@ MCgof.secr <- function (object, nsim = 100, statfn = NULL, testfn = NULL,
     if (!quiet && ncores == 1) progressbar <- txtProgressBar(0, nsim, style = 3)
     
     if (ncores > 1) {
+        if (debug>0) stop ("debugging is enabled only when ncores = 1")
         if (.Platform$OS.type != "unix") clustertype <- "PSOCK"
         clust <- makeCluster(ncores, type = clustertype)
         if (clustertype == "PSOCK") {
@@ -295,6 +315,7 @@ MCgof.secr <- function (object, nsim = 100, statfn = NULL, testfn = NULL,
         proctime = (proc.time() - ptm)[3])
     class(out) <- 'MCgof'
     
+    if (debug == 5) browser()
     if (!quiet) {
         if (ncores==1) close(progressbar)
         message ("MCgof for ", nsim, " simulations completed in ", 
