@@ -46,10 +46,10 @@ secr.fit <- function (capthist,  model = list(D~1, g0~1, sigma~1), mask = NULL,
     
     #################################################
     ## Remember start time
-    ptm  <- proc.time()
+    ptm       <- proc.time()
     starttime <- format(Sys.time(), "%H:%M:%S %d %b %Y")
-    # gc(verbose = FALSE) ## garbage collection 2019-09-02
-    
+    desc      <- packageDescription("secr")  ## for version number
+
     if (is.character(capthist)) {
         capthistname <- capthist; rm(capthist)
         capthist <- get(capthistname, pos=-1)
@@ -188,7 +188,9 @@ secr.fit <- function (capthist,  model = list(D~1, g0~1, sigma~1), mask = NULL,
         Dlambda = FALSE,
         relativeD = FALSE,
         externalpdot = NULL,
-        externalqx = NULL
+        externalqx = NULL,
+        saveprogress = FALSE,
+        progressfilename = "progress.RDS"
     )
     if (!is.null(attr(capthist,'cutval'))) {
         defaultdetails$cutval <- attr(capthist,'cutval')
@@ -283,16 +285,22 @@ secr.fit <- function (capthist,  model = list(D~1, g0~1, sigma~1), mask = NULL,
     }
     else {
         if (MS & !ms(mask)) {
-            if (inherits(mask, 'linearmask'))
+            ## inefficiently replicate mask for each session!
+            mask <- lapply(sessionlevels, function(x) mask)
+        }
+    }
+    if (MS) {
+        # fix class of multi-session mask 2025-03-17
+        if (!inherits(mask, c('linearmask','mask'))) {
+            if (inherits(mask[[1]], 'linearmask'))
                 newclass <- c('linearmask', 'mask', 'list')
             else
                 newclass <- c('mask', 'list')
-            ## inefficiently replicate mask for each session!
-            mask <- lapply(sessionlevels, function(x) mask)
             class (mask) <- newclass
             names(mask) <- sessionlevels
         }
     }
+    
     #################################################
     
     nc <- ifelse (MS, sum(sapply(capthist, nrow)), nrow(capthist))
@@ -848,6 +856,34 @@ secr.fit <- function (capthist,  model = list(D~1, g0~1, sigma~1), mask = NULL,
     betaw <- max(max(nchar(betanames)),8)   # for 'trace' formatting
     names(start) <- betanames
     
+    if (!is.null(details$saveprogress) && details$saveprogress > 0) {
+        if (is.null(details$progressfilename) || !is.character(details$progressfilename)) {
+            stop("saveprogress requires that you name the progress RDS file (details$progressfilename)")
+        }
+        if (!grepl('rds', tolower(tools::file_ext(details$progressfilename))))
+            stop ("progress file should have extension .RDS")
+        memo(paste0("Saving progress to ", details$progressfilename, 
+                    " after each ", as.integer(details$saveprogress), " evaluation(s)"), TRUE)
+        .localstuff$savedinputs <- list(
+            capthist     = capthist,
+            mask         = mask,
+            detectfn     = detectfn,
+            CL           = CL,
+            timecov      = timecov,
+            sessioncov   = sessioncov,
+            hcov         = hcov,
+            groups       = groups,
+            start        = start,
+            link         = link,
+            fixed        = fixed,
+            model        = model,
+            details      = details,
+            method       = method
+            # ,         
+            # version      = desc$Version,
+            # starttime    = starttime
+        )
+    }
     ############################################
     # Maximize likelihood
     ############################################
@@ -979,7 +1015,6 @@ secr.fit <- function (capthist,  model = list(D~1, g0~1, sigma~1), mask = NULL,
     ############################################
     ## form output list
     ############################################
-    desc <- packageDescription("secr")  ## for version number
 
     ## if density modelled then smoothsetup already contains D,noneuc
     ## otherwise an empty list; now add detection parameters from
