@@ -193,6 +193,7 @@ struct polygonhistories : public Worker {
           bool dead = false;
           double hint;
           double Tski;
+          double pskval;
           if (debug>0) Rprintf("starting prwpolygon\n");
           for (s=0; s<ss; s++) {  // over occasions
               if (binomN[s] < 0) Rcpp::stop ("negative binomN < 0 not allowed in C++ fn prwpolygon");
@@ -205,18 +206,19 @@ struct polygonhistories : public Worker {
                   if (c >= 0) {                          // skip if this polygon not used 
                       Tski = Tsk(k,s);
                       for (m=0; m<mm; m++) {
-                          if (debug>0) Rprintf("k %d, m %d \n", k,m);
                           if (mbool(n,m)) {
                               gi  = i3(c,k,m,cc,nk);
-                              pm[m] *= pski(binomN[s], count, Tski, hk[gi], 1.0);
-                              
+                              pskval = pski(binomN[s], count, Tski, hk[gi], 1.0);
+                              if (debug>0) Rprintf("n %d k %d, m %d  Tski %g gi %d hk[gi] %g pski %g \n", 
+                                  n, k, m, Tski, gi, hk[gi], pskval);
+                              pm[m] *= pskval;
                               // for each detection, pdf(xy) | detected 
                               if ((pm[m] > minp) && (count>0)) {       // avoid underflow
                                   // retrieve hint = integral2D(zfn(x) over k)) OR 1-D integral
                                   hint = hk[gi] / gsbval(c,0) * H[c];  
+                                  if (debug>0) Rprintf("each detection: start[w3] %d hint %g\n", start[w3], hint);
                                   for (j=start[w3]; j < start[w3]+count; j++) {
                                     pm[m] *= zcpp(j, m, c, gsbval, xy, mask) / hint;
-                                      
                                   }
                               }
                           }
